#ifndef OSL_TEMPLATE_H
#define OSL_TEMPLATE_H
namespace osl
{

} // namespace osl

#endif /* OSL_TEMPLATE_H */
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; coding:utf-8
// ;;; End:
